<?php
/*
* $Id: pad_multiple_dropdowns.php
* $Loc: /includes/system/override/qtpro/
*
* Name: QTPro
* Version: 7.4.14
* Release Date: 2024-10-28
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under Commercial License
*
* Comments:  Author: [Rainer Schmied @raiwa]
*  Author URI: [www.phoenixcartaddons.com]
*  License: Commercial License Rainer Schmied
*  License URI: https://www.phoenixcartaddons.com/license.php
* 
*  Copyright (c) 2024 Rainer Schmied
*  
*  Redistribution and use in source and binary forms, with or without
*  modification, are not permitted without specific prior written permission
*  from Rainer Schmied
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
*  SOFTWARE.
*  
* 
*/

  if (!class_exists('pad_multiple_dropdowns')) {
    class pad_multiple_dropdowns extends pad_base {


  /*
      Method: _draw_stocked_attributes
      draw dropdown lists for attributes that stock is tracked for
      Parameters:
        none
      Returns:
        string:         HTML to display dropdown lists for attributes that stock is tracked for
  */
      function _draw_stocked_attributes() {
        global $fr_input, $fr_required;

        $out = '';

        $attributes = $this->_build_attributes_array(true, false);
        if (sizeof($attributes) > 0) {
          for($o = 0; $o < sizeof($attributes); $o++) {
            $s = sizeof($attributes[$o]['ovals']);
            for ($a = 0; $a < $s; $a++) {
              $stock_sum = 0;
              $attributes_combination = $attributes[$o]['oid'] . '-' . $attributes[$o]['ovals'][$a]['id'];
              // loop through products_attrib_stock array and check for stock
              foreach ($this->products_attrib_stock as $attrib_combs => $stock) {
                if ( strpos($attrib_combs, $attributes_combination) !== false) {
                  $stock_sum += $stock;
                }
              }
              $out_of_stock = ($stock_sum > 0)? false : true;

              if ($this->actual_price_pull_down == 'True') {
                $attributes[$o]['ovals'][$a]['text'] .= ' ' . $GLOBALS['currencies']->display_price( $attributes[$o]['ovals'][$a]['price'] + $this->products_original_price, Tax::get_rate($this->products_tax_class_id));
              }
              if ($out_of_stock && ($this->show_out_of_stock == 'True') && !Text::is_empty($attributes[$o]['ovals'][$a]['id']) ) {
                switch ($this->mark_out_of_stock) {
                  case 'Left':   $attributes[$o]['ovals'][$a]['text'] = MODULE_CONTENT_PI_QTPRO_OPTIONS_OUT_OF_STOCK . ' - ' . $attributes[$o]['ovals'][$a]['text'];
                                 break;
                  case 'Right':  $attributes[$o]['ovals'][$a]['text'] .= ' - ' . MODULE_CONTENT_PI_QTPRO_OPTIONS_OUT_OF_STOCK;
                                 break;
                }
              } elseif ($out_of_stock && ($this->show_out_of_stock != 'True')) {
                unset($attributes[$o]['ovals'][$a]);
              }
            }
            $out .= '<div class="form-group row">' . PHP_EOL;
            $out .= ' <label for="id[' . $attributes[$o]['oid'] . ']" class="col-form-label col-sm-3 text-left text-sm-right">' . $attributes[$o]['oname'] . ': </label>' . PHP_EOL;
            $out .= ' <div class="col-sm-9">' . PHP_EOL;
            $selection = is_string($_GET['products_id'])
                         ? $_SESSION['cart']->contents[$_GET['products_id']]['attributes'][$attributes[$o]['oid']] ?? ''
                         : $attributes[$o]['default'];
            // BEGIN product optionsimages support
            if ($this->options_images) {
              $out .= $this->qtpro_draw_pull_down_menu_options('id[' . $attributes[$o]['oid'] . ']', array_values($attributes[$o]['ovals']), $selection, ' id=option' . $attributes[$o]['oid'] . ' required aria-required="true" onchange="stkmsg(this.form);"') . PHP_EOL;
            } else {
              $out .= (new Select('id[' . $attributes[$o]['oid'] . ']', array_values($attributes[$o]['ovals']), ['id' => 'option' . $attributes[$o]['oid'], 'onchange' => 'stkmsg(this.form);']))->set_selection($selection)->require();
            }
            // END product optionsimages support
            $out .= ' </div>' . PHP_EOL;
            $out .= '</div>' . PHP_EOL;
          }
          if ($this->out_of_stock_msgline == 'True') {
            $out .= '<p id="oosmsg" class=text-danger></p>' . PHP_EOL;
            $this->_draw_out_of_stock_message_js($attributes);
          }
          return $out;
        }
      }


  /*
      Method: _draw_out_of_stock_message_js
      draw Javascript to display out of stock message for out of stock attribute combinations
      Parameters:
        $attributes     array   Array of attributes for the product.  Format is as returned by
                                _build_attributes_array.
      Returns:
        string:         Javascript to display out of stock message for out of stock attribute combinations
  */
      function _draw_out_of_stock_message_js($attributes) {

        $output = null;
        if (($this->out_of_stock_msgline == 'True' | $this->no_add_out_of_stock == 'True')) {
          $output .= <<<EOD
<script>
EOD;
          $combinations = [];
          $selected_combination = 0;
          $this->_build_attributes_combinations($attributes, false, 'None', $combinations, $selected_combination);
          $draw_array_combinations = $this->_draw_js_stock_array($combinations);
          $out_of_stock_message = MODULE_CONTENT_PI_QTPRO_OPTIONS_OUT_OF_STOCK_MESSAGE;

          $output .= <<<EOD
function chkstk(frm) {
  var stk={$draw_array_combinations};
  var instk=false;
EOD;
          for ($i=0; $i<sizeof($attributes); $i++) {
            $output .= <<<EOD
 if (stk
EOD;
            for ($j = 0; $j <= $i; $j++) {
              $attributes_j_oid = $attributes[$j]['oid'];
              $output .= <<<EOD
[frm['id[{$attributes_j_oid}]'].value]
EOD;
            }
            $output .= <<<EOD
)
EOD;
          }
          $output .= <<<EOD
instk=true;
return instk;
}
EOD;
          if ($this->out_of_stock_msgline == 'True') {
            // set/reset out of stock message based on selection
            $output .= <<<EOD
function stkmsg(frm) {
  var defoption = false;
EOD;
            for ($k=0; $k<sizeof($attributes); $k++) {
              $attributes_k_oid = $attributes[$k]['oid'];
              $output .= <<<EOD
  var optionid = document.getElementById("option{$attributes_k_oid}").value;
  if (optionid < 1)
    defoption = true;
EOD;
            }
            $output .= <<<EOD
    var instk=chkstk(frm);
    var span=document.getElementById("oosmsg");
    while (span.childNodes[0])
      span.removeChild(span.childNodes[0]);
      if (!instk && !defoption)
        span.appendChild(document.createTextNode("{$out_of_stock_message}"));
      else
        span.appendChild(document.createTextNode(" "));
      }
        //initialize out of stock message
stkmsg(document.cart_quantity);
EOD;
          }
          if ($this->no_add_out_of_stock == 'True') {
            $output .= <<<EOD
    function chksel() {
      var instk=chkstk(document.cart_quantity);
      if (!instk) alert("{$out_of_stock_message}");
      return instk;
    }
    document.cart_quantity.onsubmit=chksel;
EOD;
          }
          $output .= <<<EOD
</script>
EOD;
        }
        $GLOBALS['Template']->add_block($output, 'footer_scripts');
      }

    }
  }
