<?php
/*
* $Id: pad_sequenced_dropdowns.php
* $Loc: /includes/system/override/qtpro/
*
* Name: QTPro
* Version: 7.4.14
* Release Date: 2024-10-28
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under Commercial License
*
* Comments:  Author: [Rainer Schmied @raiwa]
*  Author URI: [www.phoenixcartaddons.com]
*  License: Commercial License Rainer Schmied
*  License URI: https://www.phoenixcartaddons.com/license.php
* 
*  Copyright (c) 2024 Rainer Schmied
*  
*  Redistribution and use in source and binary forms, with or without
*  modification, are not permitted without specific prior written permission
*  from Rainer Schmied
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
*  SOFTWARE.
*  
* 
*/

  class pad_sequenced_dropdowns extends pad_multiple_dropdowns {

/*
    Method: _draw_stocked_attributes
    draw dropdown lists for attributes that stock is tracked for
    Parameters:
      none
    Returns:
      string:         HTML to display dropdown lists for attributes that stock is tracked for
*/
    function _draw_stocked_attributes() {

      $out = '';

      $attributes = $this->_build_attributes_array(true, false);
      if (sizeof($attributes) <= 1) {
        return parent::_draw_stocked_attributes();
      }

      // Check stock
      $s = sizeof($attributes[0]['ovals']);
      for ($a = 0; $a < $s; $a++) {
        $stock_sum = 0;
        $attributes_combination = $attributes[0]['oid'] . '-' . $attributes[0]['ovals'][$a]['id'];
        // loop through products_attrib_stock array and check for stock
        foreach ($this->products_attrib_stock as $attrib_combs => $stock) {
          if ( strpos($attrib_combs, $attributes_combination) !== false) {
            $stock_sum += $stock;
          }
        }
        if ($stock_sum < 1) {
          unset($attributes[0]['ovals'][$a]);
        }
      }

      for($o = 0; $o < sizeof($attributes); $o++) {
        $s = sizeof($attributes[$o]['ovals']);
        for ($a = 1; $a < $s; $a++) {
          $stock_sum = 0;
          $attributes_combination = $attributes[$o]['oid'] . '-' . $attributes[$o]['ovals'][$a]['id'];
          // loop through products_attrib_stock array and check for stock
          foreach ($this->products_attrib_stock as $attrib_combs => $stock) {
            if ( strpos($attrib_combs, $attributes_combination) !== false) {
              $stock_sum += $stock;
            }
          }
          $out_of_stock = ($stock_sum > 0)? false : true;
        }
      }

      // Draw first option dropdown with all values
      $out .= '<div class="form-group row">' . PHP_EOL;
      $out .= ' <label for="id[' . $attributes[0]['oid'] . ']" class="col-form-label col-sm-3 text-left text-sm-right">' . $attributes[0]['oname'] . ': </label>' . PHP_EOL;
      $out .= ' <div class="col-sm-9">' . PHP_EOL;
      $out .= (new Select('id[' . $attributes[0]['oid'] . ']', array_merge([['id'=>'', 'text'=>sprintf(MODULE_CONTENT_PI_QTPRO_OPTIONS_FIRST_SELECT, $attributes[0]['oname'])]], $attributes[0]['ovals']), ['onchange' => 'i' . $attributes[0]['oid'] . '(this.form);']))->set_selection($attributes[0]['default'])->require();
      $out .= ' </div>' . PHP_EOL;
      $out .= '</div>' . PHP_EOL;

      // Draw second to next to last option dropdowns - no values, with onchange
      for($o = 1; $o<sizeof($attributes)-1; $o++) {
        $out .= '<div class="form-group row">' . PHP_EOL;
        $out .= ' <label for="id[' . $attributes[$o]['oid'] . ']" class="col-form-label col-sm-3 text-left text-sm-right">' . $attributes[$o]['oname'] . ': </label>' . PHP_EOL;
        $out .= ' <div class="col-sm-9">' . PHP_EOL;
        $out .= (new Select('id[' . $attributes[$o]['oid'] . ']', [['id'=>'', 'text'=>sprintf(MODULE_CONTENT_PI_QTPRO_OPTIONS_NEXT_SELECT, $attributes[$o]['oname'])]], ['onchange' => 'i' . $attributes[$o]['oid'] . '(this.form);']))->require();
        $out .= ' </div>' . PHP_EOL;
        $out .= '</div>' . PHP_EOL;
      }

      // Draw last option dropdown - no values, no onchange
      $out .= '<div class="form-group row">' . PHP_EOL;
      $out .= ' <label for="id[' . $attributes[$o]['oid'] . ']" class="col-form-label col-sm-3 text-left text-sm-right">' . $attributes[$o]['oname'] . ': </label>' . PHP_EOL;
      $out .= ' <div class="col-sm-9">' . PHP_EOL;
      $out .= (new Select('id[' . $attributes[$o]['oid'] . ']', [['id'=>'', 'text'=>sprintf(MODULE_CONTENT_PI_QTPRO_OPTIONS_NEXT_SELECT, $attributes[$o]['oname'])]]))->require();
      $out .= ' </div>' . PHP_EOL;
      $out .= '</div>' . PHP_EOL;

      $this->_draw_dropdown_sequence_js($attributes);

      return $out;
    }


/*
    Method: _draw_dropdown_sequence_js
    draw Javascript to display out of stock message for out of stock attribute combinations
    Parameters:
      $attributes     array   Array of attributes for the product.  Format is as returned by
                              _build_attributes_array.
    Returns:
      string:         Javascript to force user to select stocked dropdowns in sequence
*/
    function _draw_dropdown_sequence_js($attributes) {

      $combinations = [];
      $selected_combination = 0;
      $this->_build_attributes_combinations($attributes, false, 'None', $combinations, $selected_combination);
      $draw_js_stock_array = $this->_draw_js_stock_array($combinations);
      $output = <<<EOD
<script>
var stk={$draw_js_stock_array};
EOD;
      for ($curattr = 1; $curattr<sizeof($attributes); $curattr++) {
        $attr = $attributes[$curattr];
        $attr_oid = $attr['oid'];
        $output .= <<<EOD
var txt{$attr_oid}={
EOD;
        foreach ($attr['ovals'] as $oval) {
          $oval_id = $oval['id'];
          $oval_text = $oval['text'];
          $output .= <<<EOD
{$oval_id}:'{$oval_text}',
EOD;
        }
        $output = substr($output,0,strlen($output)-1) . "};";
      }

      // js functions to set next dropdown options when a dropdown selection is made
      // do all but last attribute (nothing needs to happen when it changes)
      for ($curattr = 0; $curattr < sizeof($attributes)-1; $curattr++) {
        $attr = $attributes[$curattr];
        $attr_oid = $attr['oid'];
          $output .= <<<EOD
  function i{$attr_oid}(frm) {
EOD;
        $i = key($attributes);
        for ($i = $curattr+1; $i < sizeof($attributes); $i++) {
          $attributes_i_oid = $attributes[$i]['oid'];
          $output .= <<<EOD
    frm['id[{$attributes_i_oid}]'].length=1;
EOD;
        }
        $output .= <<<EOD
    for (opt in stk
EOD;
        for ($i = 0; $i <= $curattr; $i++) {
          $attributes_i_oid = $attributes[$i]['oid'];
          $attributes_curattr_plus_one_oid = $attributes[$curattr+1]['oid'];

          $output .= <<<EOD
[frm['id[{$attributes_i_oid}]'].value]
EOD;
        }

        $output .= <<<EOD
) {
      var o1 = new Option(txt{$attributes_curattr_plus_one_oid}[opt],opt);
      frm['id[{$attributes_curattr_plus_one_oid}]'].options[frm['id[{$attributes_curattr_plus_one_oid}]'].length] = o1;
    }
  }
EOD;
      }

      // js to initialize dropdowns to defaults if product id contains attributes (i.e. clicked through to product page from cart)
        $attributes_0_oid = $attributes[0]['oid'];
      $output .= <<<EOD
  i{$attributes_0_oid}(document.cart_quantity);
EOD;
      for($o = 1; $o<sizeof($attributes)-1; $o++) {
        $attributes_o_oid = $attributes[$o]['oid'];
        $attributes_o_default = $attributes[$o]['default'];

        if ($attributes[$o]['default'] != '') {
          $output .= <<<EOD
  document.cart_quantity['id[{$attributes_o_oid}]'].value={$attributes_o_default};
  i{$attributes_o_oid}(document.cart_quantity);
EOD;
        }
        else break;
      }
      if (($o == sizeof($attributes)-1) && ($attributes[$o]['default'] != '')) {
        $attributes_o_oid = $attributes[$o]['oid'];
        $attributes_o_default = $attributes[$o]['default'];
        $output .= <<<EOD
  document.cart_quantity['id[{$attributes_o_oid}]'].value={$attributes_o_default};
EOD;
      }

      // js to not allow add to cart if selections not made
      $output .= <<<EOD
  function chksel() {
    var ok=true;
EOD;
      foreach ($attributes as $attr) {
        $attr_oid = $attr['oid'];
        $show_please_select = $this->show_please_select;
        $output .= <<<EOD
    if (this['id[{$attr_oid}]'].value==0) ok=false;
EOD;
      }
      $output .= <<<EOD
    if (!ok) alert('{$show_please_select}');
    return ok;
  }
  document.cart_quantity.onsubmit=chksel;
</script>
EOD;

      $GLOBALS['Template']->add_block($output, 'footer_scripts');
    }


/*
    Method: _SetConfigurationProperties
    Set local configuration properties
    Parameters:
      $prefix      sting     Prefix for the osCommerce DB constants
    Returns:
      nothing
*/
    function _SetConfigurationProperties($prefix) {

      // These properties are not used directly by this class
      // They are set to match how this class displays for the case of a single
      // attribute where the parent class _draw_stocked_attributes method is called
      $this->show_out_of_stock    = 'False';
      $this->mark_out_of_stock    = 'Right';
      $this->out_of_stock_msgline = 'False';
      $this->no_add_out_of_stock  = 'True';
      $this->combine_non_stock  = constant($prefix . 'COMBINE_NON_STOCKED');
      $this->options_plugin  = constant($prefix . 'PLUGIN');
      $this->actual_price_pull_down  = constant($prefix . 'ACTUAL_PRICE_PULL_DOWN');
      $this->show_please_select  = constant($prefix . 'SHOW_PLEASE_SELECT');
    }
  }
